Package: infoelectoral
Type: Package
Title: Download Spanish Election Results
Version: 1.0.3
Authors@R: 
    person("Héctor", "Meleiro", 
    email = "hmeleiros@gmail.com", 
    role = c("aut", "cre"))
Maintainer: Héctor Meleiro <hmeleiros@gmail.com>
Description: Download official election results for Spain at polling station,
    municipality and province level, format them and import them to the R
    environment. Data are provided by the Spanish Ministry of the Interior
    (<https://infoelectoral.interior.gob.es/es/inicio/>).
Depends: R (>= 3.5.0)
License: GPL-2
URL: https://github.com/rOpenSpain/infoelectoral
BugReports: https://github.com/rOpenSpain/infoelectoral/issues
Encoding: UTF-8
LazyData: true
Imports: dplyr (>= 1.0.0), stringr (>= 1.0.0), httr (>= 1.0.0)
Suggests: ggplot2, mapSpain (>= 0.9.0), patchwork, purrr, tidyr, knitr,
        pkgdown, testthat (>= 3.0.0)
RoxygenNote: 7.3.2
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/Needs/website: hmeleiro/spainelectoraltheme
NeedsCompilation: no
Packaged: 2026-04-29 07:44:08 UTC; hmele
Author: Héctor Meleiro [aut, cre]
Repository: CRAN
Date/Publication: 2026-04-29 09:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 11:08:54 UTC; unix
