# Generated by roxygen2: do not edit by hand

export(candidatos)
export(mesas)
export(municipios)
export(provincias)
importFrom(dplyr,"%>%")
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,desc)
importFrom(dplyr,full_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_if)
importFrom(dplyr,relocate)
importFrom(dplyr,select)
importFrom(httr,GET)
importFrom(httr,add_headers)
importFrom(httr,stop_for_status)
importFrom(httr,timeout)
importFrom(stringr,str_remove_all)
importFrom(stringr,str_trim)
importFrom(utils,download.file)
importFrom(utils,unzip)
