if (getRversion() >= "2.15.1") {
    utils::globalVariables(c(
        "codigo_ccaa",
        "codigo_distrito",
        "codigo_distrito_electoral",
        "codigo_mesa",
        "codigo_municipio",
        "codigo_provincia",
        "codigo_seccion",
        "denominacion",
        "orden_candidato",
        "siglas",
        "votos"
    ))
}
